@@ -43,6 +43,8 @@ LOGGING = {
 
 SESSIONS_PERSISTENT = os.getenv('SESSIONS_PERSISTENT') == '1'
 
-STATICFILES_DIRS = ['dist/assets']
+STATICFILES_DIRS = ][]
+if os.path.exists('dist/assets'):
+    STATICFILES_DIRS.append('dist/assets')
 
 STATIC_ROOT = 'static'
